% testsmatching.m
%
% Matlab script that tests functionality of smatching.

% (c) Radim Sara (sara@cmp.felk.cvut.cz) FEE CTU Prague, 10 Mar 06

filt = [0.0830,0.8340,0.0830];
l = randn(256,256); % left image
l = conv2(conv2(l,filt),filt'); % some low-pass filtering
l = l(1:end-2,1:end-2);

drange = [-10,20]; % minimum and maximum disparity in synthetic example

g = [drange(1):(drange(2)-drange(1))/(size(l,2)-1):drange(2)]; % ground truth map
g = repmat(g,size(l,1),1);


figure(1)
dmap = jet(256);
dmap(1,:)=get(gcf,'Color');

imagesc(g)
colormap(dmap)
set(gca,'clim',drange)
axis image
title 'ground truth map'

[x,y]=meshgrid(1:size(l,2),1:size(l,1));
r = interp2(l,x+g,y,'cubic',0); % make sure no NaNs are in r
r = r + 0.01*randn(size(r)); % add some noise

figure(2)
imagesc(l);
axis image
colormap(gray)
title 'left image'

figure(3)
imagesc(r)
axis image
colormap(gray)
title 'right image'

% These parameters determine the quality if the disparity map.
% Increase the value of Alpha if there are mismatches in low SNR
% areas. Increase the value of Beta if there are mismatches in areas
% of repetitive texture. Values provided here should suffice in most
% cases:

alpha = 0.005*std(l(:)); 
beta = 0.02;

% Searchrange must be known in advance. Large searchrange increases
% processing time and the chance of error.

t=cputime;
d = sdm(l,r,'searchrange',[-30 30],...
	      'csalpha',alpha,'csbeta',beta);
t = cputime-t;
fprintf('matching time: %g sec\n',t)


figure(4)
imagesc(d)
colormap(dmap)
set(gca,'clim',drange)
axis image
title 'matching result'

